This crate contains kube-rs compatible bindings for Kubernetes custom resources for the confidentialcontainers.org group. Each binding is generated with kopium, updated and released weekly.
Available Custom Resources
confidentialcontainers.org/v1beta1
CcRuntime